      SUBROUTINE LPAG(A,ILAT,AN,NLP,ALP)
C 
C     * JUL 14/92 - E. CHAN (ADD REAL*8 DECLARATIONS)
C     * JUL 10/78 - J.D.HENDERSON
C     * COMPUTES DATA VALUES FROM LEGENDRE POLYNOMIAL SERIES. 
C 
C     * AN(NLP) = AMPLITUDES FOR LEGENDRE POLYNOMIAL SERIES.
C     * A(ILAT) = DATA VECTOR DEFINED ON GAUSSIAN LATITUDES.
C     * ALP(NLP,ILAT) = LEGENDRE POLYNOMIALS (NLP VALUES AT ILAT LATS). 
C 
C     * LEVEL 2,ALP 
      IMPLICIT REAL (A-H,O-Z),
     +INTEGER (I-N)
      REAL*8 ALP(NLP,ILAT)
      REAL A(ILAT),AN(NLP)
C-------------------------------------------------------------------- 
      DO 310 J=1,ILAT 
      SUM=0.E0
      DO 210 N=1,NLP
  210 SUM=SUM+AN(N)*ALP(N,J)
  310 A(J)=SUM
C 
      RETURN
      END 
